@@ -78,11 +78,13 @@ KTView::KTView(QWidget *parent, const char* name) :
   
   connect(this, SIGNAL(enableEnabled(bool)), parent,
     SLOT(slotEnableEnabled(bool)));
-  
+}
+
+void KTView::disableIcons()
+{
   emit(enableModificationButtons(false));
   emit(enablePaste(clipboardCTVariable));
-  emit(enableRunNow(false));
-            
+  emit(enableRunNow(false));        
 }
 
 void KTView::refresh()
@@ -537,7 +539,7 @@ void KTView::slotSetCurrent (QListViewItem* qlvi)
       
       emit(enableModificationButtons(true));
       emit(enableRunNow(false));
-      emit(enableEnabled(currentCTTask->enabled));
+      emit(enableEnabled(currentCTVariable->enabled));
 
     }
     else if (parent->text(0) == KTListTasks::getDescription())
