@@ -30,7 +30,7 @@
 #include "BackupProfile.h"
 #include "BackupProfileInfoWidget.h"
 #include "BackupProfileWidget.h"
-#include "KDat.h"
+#include "KDatMainWindow.h"
 #include "Options.h"
 #include <klocale.h>
 
@@ -198,12 +198,12 @@ void BackupProfileInfoWidget::slotApply()
 
 void BackupProfileInfoWidget::slotSetSelection()
 {
-    KDat::getInstance()->setBackupFiles( _profile->getAbsoluteFiles() );
+    KDatMainWindow::getInstance()->setBackupFiles( _profile->getAbsoluteFiles() );
 }
 
 void BackupProfileInfoWidget::slotGetSelection()
 {
     QStringList files;
-    KDat::getInstance()->getBackupFiles( files );
+    KDatMainWindow::getInstance()->getBackupFiles( files );
     _profile->setAbsoluteFiles( files );
 }
