@@ -158,16 +158,16 @@ void DEB::listPackList(QPtrList<packageInfo> *pki, const QString &fname, cacheOb
   kpackage->setStatus(sline);
   kpackage->setPercent(0);
 
-  char linebuf[1024];
-  FILE *file;
+  QFile file(STATUS);
   QString s;
 
-  file= fopen(QFile::encodeName(fname),"r");
-  if (file) {
-    while (fgets(linebuf,sizeof(linebuf),file)) {
-      if (strcmp(linebuf,"\n")) {
-	s = linebuf;
-	s.truncate(s.length() - 1);
+  bool fileOpened= file.open(IO_ReadOnly);
+  if (fileOpened) {
+    QTextStream stream( &file );
+    s = "";
+    while ( !s.isNull() ) {
+      s = stream.readLine();
+      if ( !s.isEmpty() ) {
 	list << s;
       } else {
 	p = collectInfo(list);
@@ -181,7 +181,7 @@ void DEB::listPackList(QPtrList<packageInfo> *pki, const QString &fname, cacheOb
 	list.clear();
       }
     }
-    fclose(file);
+    file.close();
   }
 
   kpackage->setPercent(100);
