@@ -1,5 +1,4 @@
-/* pkgOptions.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 // This provides the installation options, plus the install and cancel
@@ -20,8 +19,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -57,8 +56,8 @@ public:
   pkgOptions( pkgInterface *pki, QWidget *parent=0, const QString &caption=QString::null);
   ~pkgOptions();
 
-  void setup(QPtrList<packageInfo> *pl, QString type);
-  void setup(packageInfo *p, QString type);
+  bool setup(QPtrList<packageInfo> *pl, const QString &type);
+  void setup(packageInfo *p, const QString &type);
   void reset();
 
   virtual QString doPackages(int installFlags, QPtrList<packageInfo> *p,
@@ -68,7 +67,7 @@ public:
   // options buttons
 
   QCheckBox *Keep;
-  // keep window
+  // keep window 
 
   KListView *packages;
 
@@ -90,7 +89,7 @@ protected:
   // This sets up the sub-widgets
   void setupWidgets(QPtrList<param> &pars);
 
-private slots:
+private slots:  
   virtual void pkginstallButtonClicked();
   virtual void cancelButtonClicked();
   void slotSearch(QListViewItem *item);
@@ -122,8 +121,8 @@ protected:
 
   void getKeep();
 
-  void hideEvent(QHideEvent*);
   void showEvent (QShowEvent *);
+  void closeEvent (QCloseEvent * e );
 
   void terminate();
 };
