@@ -1,6 +1,4 @@
 /***************************************************************************
-                          trash.cpp  -  description
-                             -------------------
     begin                : Sun Oct 3 1999
     copyright            : (C) 1997-2000 by Peter Putzer
     email                : putzer@kde.org
