@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef _KU_GROUPSYSTEM_H_
@@ -29,7 +29,7 @@
 
 #include "kgroup.h"
 
-class KGroupSystem : public KGroups {
+class KGroupSystem : public KU::KGroups {
 public:
   KGroupSystem( KUserPrefsBase *cfg );
   virtual ~KGroupSystem();
