@@ -31,6 +31,8 @@
 #include <stdio.h>
 #include <fcntl.h>
 #include <ctype.h>
+#include <stdlib.h>
+#include <string.h>
 
 StringList ptable::disklist()
 {
